.. _citing:

Citing
======

If you use this library, we would appreciate it if you cite the corresponding
publication. Citing software is just as important as citing any other important
sources in your research. If you’re not sure whether or not to cite something,
`Shouldacite <https://bit.ly/shouldacite>`_ can help you decide if you should.

Below you can find the bibtex entry::

  @article{jgrapht,
    title = {{J}{G}raph{T}--{A} {J}ava {L}ibrary for {G}raph {D}ata {S}tructures and {A}lgorithms},
    author = {Michail, Dimitrios and Kinable, Joris and Naveh, Barak and Sichi, John V.},
    year = {2020},
    issue_date = {May 2020},
    publisher = {Association for Computing Machinery},
    address = {New York, NY, USA},
    volume = {46},
    number = {2},
    journal = {ACM Trans. Math. Softw.},
    month = may,
    articleno = {16},
    numpages = {29},
  }

